==> tasks-v1.8.8.zip: tasks/messages/sv/base.php <==
<?php

return [
    '1 Day before' => '1 Dag innan',
    '1 Month before' => '1 Månad innan',
    '1 Week before' => '1 Vecka innan',
    '2 Days before' => '2 Dagar innan',
    '2 Weeks before' => '2 Veckor innan',
    '3 Weeks before' => '3 Veckor innan',
    '<strong>Assigned users</strong> are allowed to process this task.' => '<strong>Tilldelade användare</strong> tillåts bearbeta denna uppgift.',
    '<strong>Confirm</strong> task deletion' => '<strong>Bekräfta</strong> borttagning av uppgift',
    '<strong>Create</strong> task list' => '<strong>Skapa</strong> lista med uppgifter',
    '<strong>Edit</strong> task' => '<strong>Ändra</strong> uppgift',
    '<strong>Edit</strong> task list' => '<strong>Ändra</strong> uppgiftslista',
    '<strong>New</strong> Task' => '<strong>Ny</strong> uppgift',
    '<strong>Task</strong> Overview' => '<strong>Överblick</strong> av uppgift',
    '<strong>Tasks</strong>' => '<strong>Uppgifter</strong>',
    '<strong>Tasks</strong> module configuration' => 'Konfiguration av <strong>Uppgifts</strong>-modul',
    '<strong>Your</strong> tasks' => '<strong>Dina</strong> uppgifter',
    'A widget is an element added to to the sidebar of a stream. In this case it provides users with a short overview of their tasks.' => 'En widget är ett element som läggs till i sidofältet i ett fllöde. I det här fallet ger den användaren en kort översikt över sina uppgifter.',
    'Accept Task' => 'Acceptera uppgift',
    'Add Deadline to space calendar' => 'Lägg till senast klar i nätverkets kalender',
    'Add checkpoint...' => 'Lägg till kontrollpunkt...',
    'Add checkpoints to the task to highlight the individual steps required to complete it.' => 'Lägg till kontrollpunkter till uppgiften för att markera de individuella steg som krävs för att slutföra den.',
    'Add entry to main navigation' => 'Lägg till post i huvudnavigeringen',
    'Add reminder' => 'Lägg till påminnelse',
    'Add responsible users' => 'Lägg till ansvariga användare',
    'Add schedule to the space calendar' => 'Lägg till schemaläggning till nätverkets kalender',
    'Add task' => 'Lägg till uppgifter',
    'Add to space calendar' => 'Lägg till i nätverkets kalender',
    'Additional options' => 'Ytterligare alternativ',
    'All Day' => 'Hela dagen',
    'Allows the user to create new tasks, the user will only be able to edit and delete own tasks' => 'Tillåter användaren att skapa nya uppgifter men också att endast ändra eller ta bort sina egna uppgifter.',
    'Allows the user to create, delete and edit tasks and lists and also sort tasks and lists' => 'Låter användaren skapa, ta bort och ändra uppgifter och listor samt sortera uppgifter och listor',
    'Allows the user to process unassigned tasks' => 'Låter användaren processa ej utdelade uppgifter',
    'Already requested' => 'Redan begärda',
    'Any user with a "Process unassigned tasks" permission can work on this task' => 'Alla användare med rättigheten "Bearbeta ej utdelade uppgifter" kan arbeta på denna uppgift',
    'Anyone can work on this task!' => 'Vem som helst kan arbeta på denna uppgift!',
    'Assign myself' => 'Tilldela mig själv',
    'Assign users' => 'Tilldela användare',
    'Assigned' => 'Tilldelad',
    'Assigned users' => 'Tilldelade användare',
    'Assignment' => 'Uppgift',
    'Assignments:' => 'Tilldelad:',
    'At least 1 Hour before' => 'Åtminstone en timme innan',
    'At least 2 Hours before' => 'Åtminstone två timmar innan',
    'Attachments' => 'Bilagor',
    'Begin Task' => 'Påbörja uppgiften',
    'Checklist Items' => 'Föremål i checklista',
    'Checklist:' => 'Checklista:',
    'Checkpoints' => 'Kontrollpunkter',
    'Choose if you want the module to appear in the main navigation.' => 'Välj om du vill att modulen ska visas i huvudnavigeringen.',
    'Close' => 'Stäng',
    'Color' => 'Färg',
    'Completed' => 'Avslutad',
    'Completed lists' => 'Färdiga listor',
    'Configure the Tasks module to meet your specific requirements and needs. You can define individual settings and for instance decide whether a widget is displayed.' => 'Konfigurera uppgiftsmodulen för att möta dina specifika krav och behov. Du kan definiera individuella inställningar och till exempel bestämma om en widget ska visas.',
    'Continue Review' => 'Fortsätt granska',
    'Create tasks' => 'Skapa uppgift',
    'Created by me' => 'Skapade av mig',
    'Date' => 'Datum',
    'Deadline at' => 'Klar senast',
    'Deadline: ' => 'Klar senast:',
    'Delete' => 'Radera',
    'Delete list' => 'Radera lista',
    'Description' => 'Beskrivning',
    'Do not remind' => 'Påminn inte',
    'Do you really want to delete this task?' => 'Vill du verkligen radera denna uppgift?',
    'Don\'t add to calendar' => 'Lägg inte till i kalender',
    'Drag entry' => 'Dra post',
    'Edit' => 'Ändra',
    'Edit item (empty field will be removed)...' => 'Ändra posten (tomma fält kommer tas bort)...',
    'Edit list' => 'Ändra lista',
    'End' => 'Slut',
    'End Date' => 'Slutdatum',
    'End Time' => 'Sluttid',
    'End date' => 'Slutdatum',
    'End time must be after start time!' => 'Sluttid måste vara efter starttid!',
    'Extend deadline request' => 'Begäran om förlängning',
    'Filter' => 'Filtrera',
    'Filter by status' => 'Filtrera efter status',
    'Filter by title' => 'Filtrera efter titel',
    'Filter tasks' => 'Filtrera uppgifter',
    'Finish Task' => 'Avsluta uppgift',
    'General' => 'Allmän',
    'General Settings' => 'Allmänna inställningar',
    'Hide this list once all tasks are completed' => 'Dölj denna lista när alla uppgifter är avslutade',
    'I\'m assigned' => 'Jag är tillagd på',
    'I\'m responsible' => 'Jag är ansvarig för',
    'If empty any user can complete the task.' => 'Om den är tom kan alla användare slutföra uppgiften.',
    'If no assigned user is selected, every space member with the permission to process unassigned tasks can process the task.' => 'Om inga användare tilldelas uppgiften kan vem som helst i nätverket bearbeta uppgiften (om de har rätt att arbeta på otilldelade uppgifter).',
    'In Progress' => 'Pågående',
    'In Review' => 'Granskas',
    'In case the review option is active, a <strong>responsible user</strong> will have to review and either reject or confirm this task before completion.' => 'Om granskningsalternativet är aktivt måste <strong>en ansvarig användare</strong> granska och antingen avslå eller bekräfta uppgiften innan den är avslutad.',
    'Invalid task list selection.' => 'Ogiltigt val a uppgiftslista.',
    'Let Task Review' => 'Låt uppgiftsgranska',
    'Main Navigation' => 'Huvudnavigering',
    'Manage tasks' => 'Hantera uppgifter',
    'Maximum number of entries in widget' => 'Maximalt antal poster i widgeten',
    'Module Widget' => 'Modulwidget',
    'New list or search' => 'Ny lista eller sökning',
    'No Scheduling set for this Task' => 'Ingen schemaläggning gjord för denna uppgift',
    'No pending tasks found' => 'Inga väntande uppgifter hittades',
    'No results found for the given filter.' => 'Inga resultat med det valda filtret',
    'Open Task' => 'Öppna uppgiften',
    'Other Tasks' => 'Andra uppgifter',
    'Overdue' => 'Försenad',
    'Overview' => 'Översikt',
    'Parent Task' => 'Övergripande uppgift',
    'Pending' => 'Väntar',
    'Pending Review' => 'Väntar på granskning',
    'Process unassigned tasks' => 'Processa ej utdelade uppgifter',
    'Ready For Review' => 'Redo för granskning',
    'Receive Notifications for Task Reminder.' => 'Ta emot notiser för uppgiftspåminnelser.',
    'Receive Notifications for Tasks (Deadline Updates, Status changes ...).' => 'Ta emot notiser gällande uppgifter (uppdatering om senast klar, statusändringar...).',
    'Reject Task' => 'Avslå uppgift',
    'Remind Mode' => 'Påminnelseläge',
    'Reminder' => 'Påminnelse',
    'Reminder sent' => 'Påminnelse skickad',
    'Reminders' => 'Påminnelser',
    'Request extension' => 'Begär förlängning',
    'Request sent' => 'Begäran skickad',
    'Reset Task' => 'Återställ uppgift',
    'Responsible' => 'Ansvarig',
    'Responsible users' => 'Ansvariga användare',
    'Review by responsible user required' => 'Granska via ansvarig användare krävs',
    'Scheduling' => 'Schemaläggning',
    'Show widget in Spaces' => 'Visa widget i forumyta',
    'Show widget on Dashboard' => 'Visa widget på tidslinje',
    'Show {count} more completed {countTasks,plural,=1{task} other{tasks}}' => 'Visa {count} fler genomförda {countTasks,plural,=1{task} other{tasks}}',
    'Sort Order' => 'Sorteringsordning',
    'Sort order' => 'Sorteringsordning',
    'Spaces' => 'Nätverk',
    'Start' => 'Starta',
    'Start Date' => 'Startdatum',
    'Start Time' => 'Starttid',
    'Start date' => 'Startdatum',
    'Starting at' => 'Börjar',
    'Status' => 'Status',
    'Task' => 'Uppgift',
    'Task List' => 'Uppgiftslista',
    'Task Users have been notified' => 'Uppgiftens användare har blivit meddelade',
    'Task {task} in space {spaceName} ends at {dateTime}.' => 'Uppgiften {task} i nätverket {spaceName} slutar {dateTime}.',
    'Task {task} in space {spaceName} starts at {dateTime}.' => 'Uppgiften {task} i nätverket {spaceName} börjar {dateTime}.',
    'Tasks' => 'Uppgifter',
    'Tasks: Reminder' => 'Uppgifter: Påminnelse',
    'This task can only be processed by assigned and responsible users.' => 'Den här uppgiften kan endast bearbetas av de som är tillagda och ansvariga.',
    'This task requires to be reviewed by a responsible' => 'Den här uppgiften behöver granskas av någon ansvarig',
    'Time Zone' => 'Tidszon',
    'Title' => 'Titel',
    'Title and Color' => 'Titel och färg',
    'Title of your task list' => 'Titeln på din uppgiftslista',
    'Today' => 'I dag',
    'Unsorted' => 'Osorterade',
    'View Online' => 'Se online',
    'You are assigned!' => 'Du är tilldelad!',
    'You are responsible!' => 'Du är ansvarig!',
    'You have insufficient permissions to perform that operation!' => 'Du har inte tillräckliga rättigheter för att uföra den åtgärden!',
    'Your Reminder for task {task}' => 'Din påminnelse för uppgiften {task}.',
    'ending Review' => 'avslutar granskning',
    'view all' => 'se alla',
    '{count,plural,=1{# day} other{# days}} remaining' => '{count,plural,=1{# day} other{# days}} remaining',
    '{displayName} is assigned to this task' => '{displayName} är tilldelad uppgiften',
    '{displayName} is responsible for this task' => '{displayName} är ansvarig för uppgiften',
    '{userName} assigned you as responsible person in task {task} from space {spaceName}.' => '{userName} angav dig som ansvarig för uppgiften {task} i {spaceName}.',
    '{userName} assigned you to task {task} in space {spaceName}.' => '{userName} har tilldelat dig uppgiften {task} i nätverket {spaceName}.',
    '{userName} completed Task {task} in space {spaceName}.' => '{userName} avslutade uppgiften {task} i nätverket {spaceName}.',
    '{userName} completed task {task}.' => '{userName} utförde uppgiften {task}.',
    '{userName} finished task {task}.' => '{userName} avslutade uppgiften {task}.',
    '{userName} has changed deadline for task {task} in space {spaceName}.' => '{userName} har ändrat "klar senast" för uppgiften {task} i nätverket {spaceName}.',
    '{userName} has re-opened task {task} in space {spaceName}.' => '{userName} har återöppnat uppgiften {task} i nätverket {spaceName}.',
    '{userName} has rejected task {task} in space {spaceName} as incomplete.' => '{userName} har nekat uppgiften {task} i nätverket {spaceName} som ofullständig.',
    '{userName} marked Task {task} in space {spaceName} as completed.' => '{userName} har markerat uppgiften {task} i nätverket {spaceName} som avklarad.',
    '{userName} requests a deadline extension for task {task} in space {spaceName}.' => '{userName} begär förlängning av uppgiften {task} i nätverket {spaceName}.',
    '{userName} requests you to review Task {task} in space {spaceName}.' => '{userName} begär att du ska granska uppgiften {task} i nätverket {spaceName}.',
    '{userName} reset task {task}.' => '{userName} återställde uppgiften {task}.',
    '{userName} reviewed task {task}.' => '{userName} granskade uppgiften {task}.',
    '{userName} started working on Task {task} in space {spaceName}.' => '{userName} började arbeta på uppgiften {task} i nätverket {spaceName}.',
    '{userName} works on task {task}.' => '{userName} arbetar på uppgiften {task}.',
    'Task content ID' => '',
];

==> tasks-v1.9.1.zip: tasks/messages/sv/base.php <==
<?php

return [
    '1 Day before' => '1 Dag innan',
    '1 Month before' => '1 Månad innan',
    '1 Week before' => '1 Vecka innan',
    '2 Days before' => '2 Dagar innan',
    '2 Weeks before' => '2 Veckor innan',
    '3 Weeks before' => '3 Veckor innan',
    '<strong>Assigned users</strong> are allowed to process this task.' => '<strong>Tilldelade användare</strong> tillåts bearbeta denna uppgift.',
    '<strong>Confirm</strong> task deletion' => '<strong>Bekräfta</strong> borttagning av uppgift',
    '<strong>Create</strong> task list' => '<strong>Skapa</strong> lista med uppgifter',
    '<strong>Edit</strong> task' => '<strong>Ändra</strong> uppgift',
    '<strong>Edit</strong> task list' => '<strong>Ändra</strong> uppgiftslista',
    '<strong>New</strong> Task' => '<strong>Ny</strong> uppgift',
    '<strong>Task</strong> Overview' => '<strong>Överblick</strong> av uppgift',
    '<strong>Tasks</strong>' => '<strong>Uppgifter</strong>',
    '<strong>Tasks</strong> module configuration' => 'Konfiguration av <strong>Uppgifts</strong>-modul',
    '<strong>Your</strong> tasks' => '<strong>Dina</strong> uppgifter',
    'A widget is an element added to to the sidebar of a stream. In this case it provides users with a short overview of their tasks.' => 'En widget är ett element som läggs till i sidofältet i ett fllöde. I det här fallet ger den användaren en kort översikt över sina uppgifter.',
    'Accept Task' => 'Acceptera uppgift',
    'Add Deadline to space calendar' => 'Lägg till senast klar i nätverkets kalender',
    'Add checkpoint...' => 'Lägg till kontrollpunkt...',
    'Add checkpoints to the task to highlight the individual steps required to complete it.' => 'Lägg till kontrollpunkter till uppgiften för att markera de individuella steg som krävs för att slutföra den.',
    'Add entry to main navigation' => 'Lägg till post i huvudnavigeringen',
    'Add reminder' => 'Lägg till påminnelse',
    'Add responsible users' => 'Lägg till ansvariga användare',
    'Add schedule to the space calendar' => 'Lägg till schemaläggning till nätverkets kalender',
    'Add task' => 'Lägg till uppgifter',
    'Add to space calendar' => 'Lägg till i nätverkets kalender',
    'Additional options' => 'Ytterligare alternativ',
    'All Day' => 'Hela dagen',
    'Allows the user to create new tasks, the user will only be able to edit and delete own tasks' => 'Tillåter användaren att skapa nya uppgifter men också att endast ändra eller ta bort sina egna uppgifter.',
    'Allows the user to create, delete and edit tasks and lists and also sort tasks and lists' => 'Låter användaren skapa, ta bort och ändra uppgifter och listor samt sortera uppgifter och listor',
    'Allows the user to process unassigned tasks' => 'Låter användaren processa ej utdelade uppgifter',
    'Already requested' => 'Redan begärda',
    'Assign myself' => 'Tilldela mig själv',
    'Assign users' => 'Tilldela användare',
    'Assigned users' => 'Tilldelade användare',
    'Assignment' => 'Uppgift',
    'At least 1 Hour before' => 'Åtminstone en timme innan',
    'At least 2 Hours before' => 'Åtminstone två timmar innan',
    'Attachments' => 'Bilagor',
    'Begin Task' => 'Påbörja uppgiften',
    'Checklist Items' => 'Föremål i checklista',
    'Checklist:' => 'Checklista:',
    'Checkpoints' => 'Kontrollpunkter',
    'Choose if you want the module to appear in the main navigation.' => 'Välj om du vill att modulen ska visas i huvudnavigeringen.',
    'Close' => 'Stäng',
    'Color' => 'Färg',
    'Completed' => 'Avslutad',
    'Completed lists' => 'Färdiga listor',
    'Configure the Tasks module to meet your specific requirements and needs. You can define individual settings and for instance decide whether a widget is displayed.' => 'Konfigurera uppgiftsmodulen för att möta dina specifika krav och behov. Du kan definiera individuella inställningar och till exempel bestämma om en widget ska visas.',
    'Continue Review' => 'Fortsätt granska',
    'Create tasks' => 'Skapa uppgift',
    'Created by me' => 'Skapade av mig',
    'Date' => 'Datum',
    'Deadline: ' => 'Klar senast:',
    'Delete' => 'Radera',
    'Delete list' => 'Radera lista',
    'Description' => 'Beskrivning',
    'Do not remind' => 'Påminn inte',
    'Do you really want to delete this task?' => 'Vill du verkligen radera denna uppgift?',
    'Don\'t add to calendar' => 'Lägg inte till i kalender',
    'Edit' => 'Ändra',
    'Edit item (empty field will be removed)...' => 'Ändra posten (tomma fält kommer tas bort)...',
    'Edit list' => 'Ändra lista',
    'End' => 'Slut',
    'End Date' => 'Slutdatum',
    'End Time' => 'Sluttid',
    'End date' => 'Slutdatum',
    'End time must be after start time!' => 'Sluttid måste vara efter starttid!',
    'Extend deadline request' => 'Begäran om förlängning',
    'Filter' => 'Filtrera',
    'Filter by status' => 'Filtrera efter status',
    'Filter by title' => 'Filtrera efter titel',
    'Filter tasks' => 'Filtrera uppgifter',
    'Finish Task' => 'Avsluta uppgift',
    'General' => 'Allmän',
    'General Settings' => 'Allmänna inställningar',
    'Hide this list once all tasks are completed' => 'Dölj denna lista när alla uppgifter är avslutade',
    'I\'m assigned' => 'Jag är tillagd på',
    'I\'m responsible' => 'Jag är ansvarig för',
    'If empty any user can complete the task.' => 'Om den är tom kan alla användare slutföra uppgiften.',
    'If no assigned user is selected, every space member with the permission to process unassigned tasks can process the task.' => 'Om inga användare tilldelas uppgiften kan vem som helst i nätverket bearbeta uppgiften (om de har rätt att arbeta på otilldelade uppgifter).',
    'In Progress' => 'Pågående',
    'In Review' => 'Granskas',
    'In case the review option is active, a <strong>responsible user</strong> will have to review and either reject or confirm this task before completion.' => 'Om granskningsalternativet är aktivt måste <strong>en ansvarig användare</strong> granska och antingen avslå eller bekräfta uppgiften innan den är avslutad.',
    'Invalid task list selection.' => 'Ogiltigt val a uppgiftslista.',
    'Let Task Review' => 'Låt uppgiftsgranska',
    'Main Navigation' => 'Huvudnavigering',
    'Manage tasks' => 'Hantera uppgifter',
    'Maximum number of entries in widget' => 'Maximalt antal poster i widgeten',
    'Module Widget' => 'Modulwidget',
    'New list or search' => 'Ny lista eller sökning',
    'No Scheduling set for this Task' => 'Ingen schemaläggning gjord för denna uppgift',
    'No pending tasks found' => 'Inga väntande uppgifter hittades',
    'No results found for the given filter.' => 'Inga resultat med det valda filtret',
    'Open Task' => 'Öppna uppgiften',
    'Other Tasks' => 'Andra uppgifter',
    'Overdue' => 'Försenad',
    'Overview' => 'Översikt',
    'Parent Task' => 'Övergripande uppgift',
    'Pending' => 'Väntar',
    'Pending Review' => 'Väntar på granskning',
    'Process unassigned tasks' => 'Processa ej utdelade uppgifter',
    'Ready For Review' => 'Redo för granskning',
    'Receive Notifications for Task Reminder.' => 'Ta emot notiser för uppgiftspåminnelser.',
    'Receive Notifications for Tasks (Deadline Updates, Status changes ...).' => 'Ta emot notiser gällande uppgifter (uppdatering om senast klar, statusändringar...).',
    'Reject Task' => 'Avslå uppgift',
    'Remind Mode' => 'Påminnelseläge',
    'Reminder' => 'Påminnelse',
    'Reminder sent' => 'Påminnelse skickad',
    'Reminders' => 'Påminnelser',
    'Request extension' => 'Begär förlängning',
    'Request sent' => 'Begäran skickad',
    'Reset Task' => 'Återställ uppgift',
    'Responsible' => 'Ansvarig',
    'Responsible users' => 'Ansvariga användare',
    'Review by responsible user required' => 'Granska via ansvarig användare krävs',
    'Scheduling' => 'Schemaläggning',
    'Show widget in Spaces' => 'Visa widget i forumyta',
    'Show widget on Dashboard' => 'Visa widget på tidslinje',
    'Show {count} more completed {countTasks,plural,=1{task} other{tasks}}' => 'Visa {count} fler genomförda {countTasks,plural,=1{task} other{tasks}}',
    'Sort Order' => 'Sorteringsordning',
    'Sort order' => 'Sorteringsordning',
    'Spaces' => 'Nätverk',
    'Start' => 'Starta',
    'Start Date' => 'Startdatum',
    'Start Time' => 'Starttid',
    'Start date' => 'Startdatum',
    'Starting at' => 'Börjar',
    'Status' => 'Status',
    'Task' => 'Uppgift',
    'Task List' => 'Uppgiftslista',
    'Task Users have been notified' => 'Uppgiftens användare har blivit meddelade',
    'Task {task} in space {spaceName} ends at {dateTime}.' => 'Uppgiften {task} i nätverket {spaceName} slutar {dateTime}.',
    'Task {task} in space {spaceName} starts at {dateTime}.' => 'Uppgiften {task} i nätverket {spaceName} börjar {dateTime}.',
    'Tasks' => 'Uppgifter',
    'Tasks: Reminder' => 'Uppgifter: Påminnelse',
    'This task requires to be reviewed by a responsible' => 'Den här uppgiften behöver granskas av någon ansvarig',
    'Time Zone' => 'Tidszon',
    'Title' => 'Titel',
    'Title and Color' => 'Titel och färg',
    'Title of your task list' => 'Titeln på din uppgiftslista',
    'Today' => 'I dag',
    'Unsorted' => 'Osorterade',
    'View Online' => 'Se online',
    'You have insufficient permissions to perform that operation!' => 'Du har inte tillräckliga rättigheter för att uföra den åtgärden!',
    'Your Reminder for task {task}' => 'Din påminnelse för uppgiften {task}.',
    'view all' => 'se alla',
    '{count,plural,=1{# day} other{# days}} remaining' => '{count,plural,=1{# day} other{# days}} remaining',
    '{displayName} is assigned to this task' => '{displayName} är tilldelad uppgiften',
    '{displayName} is responsible for this task' => '{displayName} är ansvarig för uppgiften',
    '{userName} assigned you as responsible person in task {task} from space {spaceName}.' => '{userName} angav dig som ansvarig för uppgiften {task} i {spaceName}.',
    '{userName} assigned you to task {task} in space {spaceName}.' => '{userName} har tilldelat dig uppgiften {task} i nätverket {spaceName}.',
    '{userName} completed Task {task} in space {spaceName}.' => '{userName} avslutade uppgiften {task} i nätverket {spaceName}.',
    '{userName} completed task {task}.' => '{userName} utförde uppgiften {task}.',
    '{userName} finished task {task}.' => '{userName} avslutade uppgiften {task}.',
    '{userName} has changed deadline for task {task} in space {spaceName}.' => '{userName} har ändrat "klar senast" för uppgiften {task} i nätverket {spaceName}.',
    '{userName} has re-opened task {task} in space {spaceName}.' => '{userName} har återöppnat uppgiften {task} i nätverket {spaceName}.',
    '{userName} has rejected task {task} in space {spaceName} as incomplete.' => '{userName} har nekat uppgiften {task} i nätverket {spaceName} som ofullständig.',
    '{userName} marked Task {task} in space {spaceName} as completed.' => '{userName} har markerat uppgiften {task} i nätverket {spaceName} som avklarad.',
    '{userName} requests a deadline extension for task {task} in space {spaceName}.' => '{userName} begär förlängning av uppgiften {task} i nätverket {spaceName}.',
    '{userName} requests you to review Task {task} in space {spaceName}.' => '{userName} begär att du ska granska uppgiften {task} i nätverket {spaceName}.',
    '{userName} reset task {task}.' => '{userName} återställde uppgiften {task}.',
    '{userName} reviewed task {task}.' => '{userName} granskade uppgiften {task}.',
    '{userName} started working on Task {task} in space {spaceName}.' => '{userName} började arbeta på uppgiften {task} i nätverket {spaceName}.',
    '{userName} works on task {task}.' => '{userName} arbetar på uppgiften {task}.',
    'Assignments' => '',
    'Deadline' => '',
    'ID' => '',
    'Request Review' => '',
    'Task content ID' => '',
    '{displayName} is task creator' => '',
];
